@@ -30,11 +30,13 @@
 
 #include <glib-object.h>
 
+#include <cairo.h>
+
 G_BEGIN_DECLS
 
-#define GOG_GRAPH_TYPE	(gog_graph_get_type ())
-#define GOG_GRAPH(o)	(G_TYPE_CHECK_INSTANCE_CAST ((o), GOG_GRAPH_TYPE, GogGraph))
-#define IS_GOG_GRAPH(o)	(G_TYPE_CHECK_INSTANCE_TYPE ((o), GOG_GRAPH_TYPE))
+#define GOG_TYPE_GRAPH	(gog_graph_get_type ())
+#define GOG_GRAPH(o)	(G_TYPE_CHECK_INSTANCE_CAST ((o), GOG_TYPE_GRAPH, GogGraph))
+#define GOG_IS_GRAPH(o)	(G_TYPE_CHECK_INSTANCE_TYPE ((o), GOG_TYPE_GRAPH))
 
 GType gog_graph_get_type (void);
 
@@ -57,9 +59,9 @@ void      gog_graph_unref_data    (GogGraph *graph, GOData *dat);
 void	  gog_graph_get_size 	  (GogGraph *graph, double *width, double *height);
 void      gog_graph_set_size      (GogGraph *graph, double width, double height);
 
-#define GOG_GRAPH_VIEW_TYPE	(gog_graph_view_get_type ())
-#define GOG_GRAPH_VIEW(o)	(G_TYPE_CHECK_INSTANCE_CAST ((o), GOG_GRAPH_VIEW_TYPE, GogGraphView))
-#define IS_GOG_GRAPH_VIEW(o)	(G_TYPE_CHECK_INSTANCE_TYPE ((o), GOG_GRAPH_VIEW_TYPE))
+#define GOG_TYPE_GRAPH_VIEW	(gog_graph_view_get_type ())
+#define GOG_GRAPH_VIEW(o)	(G_TYPE_CHECK_INSTANCE_CAST ((o), GOG_TYPE_GRAPH_VIEW, GogGraphView))
+#define GOG_IS_GRAPH_VIEW(o)	(G_TYPE_CHECK_INSTANCE_TYPE ((o), GOG_TYPE_GRAPH_VIEW))
 
 GType gog_graph_view_get_type (void);
 
@@ -68,7 +70,7 @@ void 	 gog_graph_view_set_selection   (GogGraphView *gview, GogObject *gobj);
 
 
 GSList 	 *gog_graph_get_supported_image_formats	(void);
-gboolean  gog_graph_export_image 		(GogGraph *graph, GOImageFormat format, 
+gboolean  gog_graph_export_image 		(GogGraph *graph, GOImageFormat format,
 						 GsfOutput *output, double x_dpi, double y_dpi);
 
 #ifdef GOFFICE_WITH_GTK
@@ -76,7 +78,7 @@ gboolean  gog_graph_export_image 		(GogGraph *graph, GOImageFormat format,
 void  	 gog_graph_view_handle_event 	(GogGraphView *gview, GdkEvent *event, double x_offset, double y_offset);
 #endif
 
-void gog_graph_render_to_cairo (GogGraph *graph, gpointer data, double w, double h);
+void 	 gog_graph_render_to_cairo 	(GogGraph *graph, cairo_t *cairo, double w, double h);
 
 G_END_DECLS
 
