@@ -22,42 +22,44 @@
 #ifndef GOG_REG_CURVE_H
 #define GOG_REG_CURVE_H
 
+#include <goffice/graph/gog-trend-line.h>
 #include <goffice/graph/gog-series.h>
 #include <goffice/graph/gog-data-set.h>
-#include <gtk/gtktable.h>
+
+G_BEGIN_DECLS
 
 struct  _GogRegCurve {
-	GogStyledObject	base;
+	GogTrendLine	base;
 	
 	GogSeries 	  *series;
 	gboolean  	   weighted;
 	GODataVector 	  *weights;
 	GogDatasetElement *bounds;
-	gboolean skip_invalid; /* do not take into account invalid data */
-	int ninterp; /* how many points to use for display the curve as a vpath */
-	double *a; /* calculated coefficients, must be allocated by derived class */
-	double R2; /* squared regression coefficient */
-	char *equation;
+	gboolean	   skip_invalid; /* do not take into account invalid data */
+	int		   ninterp;	 /* how many points to use for display the curve as a vpath */
+	double		  *a;		 /* calculated coefficients, must be allocated by derived class */
+	double		   R2;		 /* squared regression coefficient */
+	char		  *equation;
 };
 
 typedef struct {
-	GogStyledObjectClass base;
+	GogTrendLineClass base;
 
 	double 		(*get_value_at) (GogRegCurve *reg_curve, double x);
 	gchar const* 	(*get_equation) (GogRegCurve *reg_curve);
-	void 	(*populate_editor) (GogRegCurve *reg_curve, GtkTable *table);
+	void 		(*populate_editor) (GogRegCurve *reg_curve, gpointer table);
 } GogRegCurveClass;
 
-#define GOG_REG_CURVE_TYPE	(gog_reg_curve_get_type ())
-#define GOG_REG_CURVE(o)	(G_TYPE_CHECK_INSTANCE_CAST ((o), GOG_REG_CURVE_TYPE, GogRegCurve))
-#define IS_GOG_REG_CURVE(o)	(G_TYPE_CHECK_INSTANCE_TYPE ((o), GOG_REG_CURVE_TYPE))
+#define GOG_TYPE_REG_CURVE	(gog_reg_curve_get_type ())
+#define GOG_REG_CURVE(o)	(G_TYPE_CHECK_INSTANCE_CAST ((o), GOG_TYPE_REG_CURVE, GogRegCurve))
+#define GOG_IS_REG_CURVE(o)	(G_TYPE_CHECK_INSTANCE_TYPE ((o), GOG_TYPE_REG_CURVE))
 
 GType gog_reg_curve_get_type (void);
 
-GogRegCurve *gog_reg_curve_new_by_name  (char const *id);
-GogRegCurve *gog_reg_curve_new_by_type  (GogRegCurveType const *type);
 gchar const *gog_reg_curve_get_equation (GogRegCurve *reg_curve);
 double       gog_reg_curve_get_R2       (GogRegCurve *reg_curve);
 void         gog_reg_curve_get_bounds   (GogRegCurve *reg_curve, double *xmin, double *xmax);
 
+G_END_DECLS
+
 #endif /* GOG_REG_CURVE_H */
