@@ -1,5 +1,5 @@
 /* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
-/**
+/*
  * go-format-sel.c: A widget to select a format
  *
  * Copyright (C) 2006-2007 Morten Welinder (terra@gnome.org)
@@ -17,7 +17,7 @@
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
- **/
+ */
 
 #include <goffice/goffice-config.h>
 #include "go-format-sel.h"
@@ -140,7 +140,7 @@ struct  _GOFormatSel {
 		} formats;
 
 		gulong          entry_changed_id;
-		GOFormat	*spec;
+		GOFormat const	*spec;
 		gint		current_type;
 		int		num_decimals;
 		int		negative_format;
@@ -371,7 +371,7 @@ static void
 draw_format_preview (GOFormatSel *gfs, gboolean regen_format)
 {
 	char *preview;
-	GOFormat *sf = NULL;
+	GOFormat const *sf = NULL;
 	GOColor c = 0;
 	GdkColor gdk_color;
 	gsize len;
@@ -1164,7 +1164,7 @@ set_format_category_menu_from_style (GOFormatSel *gfs)
 {
 	GOFormatFamily page;
 
-	g_return_if_fail (IS_GO_FORMAT_SEL (gfs));
+	g_return_if_fail (GO_IS_FORMAT_SEL (gfs));
 
 	/* Attempt to extract general parameters from the current format */
 	page = study_format (gfs);
@@ -1254,7 +1254,7 @@ nfs_init (GOFormatSel *gfs)
 
 	GtkWidget *tmp;
 	GtkTreeViewColumn *column;
-	GoComboText *combo;
+	GOComboText *combo;
 	char const *name;
 	int i;
 	GOFormatFamily page;
@@ -1266,7 +1266,7 @@ nfs_init (GOFormatSel *gfs)
 	gfs->show_format_with_markup = FALSE;
 	gfs->locale = NULL;
 
-	gfs->gui = go_libglade_new ("go-format-sel.glade", NULL, GETTEXT_PACKAGE, NULL);
+	gfs->gui = go_glade_new ("go-format-sel.glade", NULL, GETTEXT_PACKAGE, NULL);
 	if (gfs->gui == NULL)
 		return;
 
@@ -1507,7 +1507,7 @@ go_format_sel_new_full (gboolean use_markup)
 {
 	GOFormatSel *gfs;
 
-	gfs = g_object_new (GO_FORMAT_SEL_TYPE, NULL);
+	gfs = g_object_new (GO_TYPE_FORMAT_SEL, NULL);
 
 	if (gfs != NULL)
 		gfs->show_format_with_markup = use_markup;
@@ -1534,24 +1534,23 @@ go_format_sel_new (void)
 void
 go_format_sel_set_focus (GOFormatSel *gfs)
 {
-	g_return_if_fail (IS_GO_FORMAT_SEL (gfs));
+	g_return_if_fail (GO_IS_FORMAT_SEL (gfs));
 
 	gtk_widget_grab_focus (GTK_WIDGET (gfs->format.menu));
 }
 
 void
 go_format_sel_set_style_format (GOFormatSel *gfs,
-				GOFormat *style_format)
+				GOFormat const *style_format)
 {
-	GoComboText *combo;
+	GOComboText *combo;
 
-	g_return_if_fail (IS_GO_FORMAT_SEL (gfs));
+	g_return_if_fail (GO_IS_FORMAT_SEL (gfs));
 	g_return_if_fail (style_format != NULL);
+	g_return_if_fail (!go_format_is_markup (style_format));
 
 	go_format_ref (style_format);
-
 	go_format_unref (gfs->format.spec);
-
 	gfs->format.spec = style_format;
 
 	study_format (gfs);
@@ -1570,7 +1569,7 @@ void
 go_format_sel_set_dateconv (GOFormatSel *gfs,
 			    GODateConventions const *date_conv)
 {
-	g_return_if_fail (IS_GO_FORMAT_SEL (gfs));
+	g_return_if_fail (GO_IS_FORMAT_SEL (gfs));
 	g_return_if_fail (date_conv != NULL);
 
 	/* FIXME is it safe ? */
@@ -1580,24 +1579,24 @@ go_format_sel_set_dateconv (GOFormatSel *gfs,
 	draw_format_preview (gfs, TRUE);
 }
 
-GOFormat *
+GOFormat const *
 go_format_sel_get_fmt (GOFormatSel *gfs)
 {
-	g_return_val_if_fail (IS_GO_FORMAT_SEL (gfs), NULL);
+	g_return_val_if_fail (GO_IS_FORMAT_SEL (gfs), NULL);
 	return gfs->format.spec;
 }
 
 GODateConventions const *
 go_format_sel_get_dateconv (GOFormatSel *gfs)
 {
-	g_return_val_if_fail (IS_GO_FORMAT_SEL (gfs), NULL);
+	g_return_val_if_fail (GO_IS_FORMAT_SEL (gfs), NULL);
 	return gfs->date_conv;
 }
 
 void
 go_format_sel_show_preview (GOFormatSel *gfs)
 {
-	g_return_if_fail (IS_GO_FORMAT_SEL (gfs));
+	g_return_if_fail (GO_IS_FORMAT_SEL (gfs));
 	gtk_widget_show (gfs->format.preview_box);
 	draw_format_preview (gfs, TRUE);
 }
@@ -1605,7 +1604,7 @@ go_format_sel_show_preview (GOFormatSel *gfs)
 void
 go_format_sel_hide_preview (GOFormatSel *gfs)
 {
-	g_return_if_fail (IS_GO_FORMAT_SEL (gfs));
+	g_return_if_fail (GO_IS_FORMAT_SEL (gfs));
 	gtk_widget_hide (gfs->format.preview_box);
 }
 
@@ -1613,7 +1612,7 @@ void
 go_format_sel_editable_enters (GOFormatSel *gfs,
 			       GtkWindow *window)
 {
-	g_return_if_fail (IS_GO_FORMAT_SEL (gfs));
+	g_return_if_fail (GO_IS_FORMAT_SEL (gfs));
 	go_gtk_editable_enters (window, gfs->format.widget[F_DECIMAL_SPIN]);
 	go_gtk_editable_enters (window, gfs->format.widget[F_ENTRY]);
 }
